@@ -103,7 +103,7 @@
 	if(is.null(dim(newdat))==FALSE) 
   	{for(j in 1:ncol(newdat))
   	    {mod <- refdf$type[j]
-  	    if(mod=="date"){ newdat[,j] <- as.Date(as.character(newdat[,j]), "%d %b %Y %H:%M:%S %Z")}else
+  	    if(mod=="date"){ newdat[,j] <- as.Date(as.character(newdat[,j]), "%d %b %Y %H:%M:%S")}else
 	    if(mod=="string"){	suppressWarnings(mode(newdat[,j]) <- "character")} else
   	    if(mod=="int"){ suppressWarnings(mode(newdat[,j]) <- "numeric")} else
   	    if(mod=="boolean"){suppressWarnings(mode(newdat[,j]) <- "logical")} else
@@ -113,7 +113,7 @@
 	## Set mode for single column of data
 	if(is.null(dim(newdat))==TRUE & length(newdat)>1) 
 	{mod <- refdf$type
-  	if(mod=="date"){ newdat <- as.Date(as.character(newdat), "%d %b %Y %H:%M:%S %Z")}else
+  	if(mod=="date"){ newdat <- as.Date(as.character(newdat), "%d %b %Y %H:%M:%S")}else
   	if(mod=="string"){suppressWarnings(mode(newdat) <- "character")} else
   	if(mod=="int"){ suppressWarnings(mode(newdat) <- "numeric")} else
   	if(mod=="boolean"){suppressWarnings(mode(newdat) <- "logical")} else
@@ -158,4 +158,4 @@ return(filtered)
   	    	} 
   	}    	
   	return (rname)
-}
\ No newline at end of file
+}
